<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu_HU">
<context>
    <name>AuthenticationWidget</name>
    <message>
        <location filename="../src/GUI/authenticationwidget.cpp" line="15"/>
        <source>Username:</source>
        <translation>Felhasználónév:</translation>
    </message>
    <message>
        <location filename="../src/GUI/authenticationwidget.cpp" line="16"/>
        <source>Password:</source>
        <translation>Jelszó:</translation>
    </message>
</context>
<context>
    <name>CadenceGraph</name>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="11"/>
        <source>rpm</source>
        <translation>ford./perc</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="12"/>
        <location filename="../src/GUI/cadencegraph.h" line="16"/>
        <source>Cadence</source>
        <translation>Ütem</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="28"/>
        <source>Avg</source>
        <translation>Átl.</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="30"/>
        <source>Max</source>
        <translation>Max</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="33"/>
        <source>Average</source>
        <translation>Átlag</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="35"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
</context>
<context>
    <name>CadenceGraphItem</name>
    <message>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="18"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="19"/>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="21"/>
        <source>rpm</source>
        <translation>ford./perc</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="20"/>
        <source>Average</source>
        <translation>Átlag</translation>
    </message>
</context>
<context>
    <name>Data</name>
    <message>
        <location filename="../src/data/data.cpp" line="160"/>
        <source>Supported files</source>
        <translation>Támogatott fájlok</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="161"/>
        <source>CSV files</source>
        <translation>CSV fájlok</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="162"/>
        <source>CUP files</source>
        <translation>CUP fájlok</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="163"/>
        <source>FIT files</source>
        <translation>FIT fájlok</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="164"/>
        <source>GeoJSON files</source>
        <translation>GeoJSON fájlok</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="165"/>
        <source>GPI files</source>
        <translation>GPI fájlok</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="166"/>
        <source>GPX files</source>
        <translation>GPX fájlok</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="167"/>
        <source>IGC files</source>
        <translation>IGC fájlok</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="168"/>
        <source>ITN files</source>
        <translation>ITN fájlok</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="169"/>
        <source>JPEG images</source>
        <translation>JPEG képek</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="170"/>
        <source>KML files</source>
        <translation>KML fájlok</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="171"/>
        <source>LOC files</source>
        <translation>LOC fájlok</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="172"/>
        <source>NMEA files</source>
        <translation>NMEA fájlok</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="173"/>
        <source>ONmove files</source>
        <translation>ONmove fájlok</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="174"/>
        <source>OV2 files</source>
        <translation>OV2 fájlok</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="175"/>
        <source>OziExplorer files</source>
        <translation>OziExplorer fájlok</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="176"/>
        <source>SLF files</source>
        <translation>SLF fájlok</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="177"/>
        <source>SML files</source>
        <translation>SML fájlok</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="178"/>
        <source>TCX files</source>
        <translation>TCX fájlok</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="179"/>
        <source>TwoNav files</source>
        <translation>TwoNav fájlok</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="180"/>
        <source>GPSDump files</source>
        <translation>GPSDump fájlok</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="181"/>
        <source>All files</source>
        <translation>Minden fájl</translation>
    </message>
</context>
<context>
    <name>DirSelectWidget</name>
    <message>
        <location filename="../src/GUI/dirselectwidget.cpp" line="18"/>
        <source>System default</source>
        <translation>Rendszer alapértelmezett</translation>
    </message>
    <message>
        <location filename="../src/GUI/dirselectwidget.cpp" line="40"/>
        <source>Select directory</source>
        <translation>Könyvtár választása</translation>
    </message>
</context>
<context>
    <name>ElevationGraph</name>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="39"/>
        <location filename="../src/GUI/elevationgraph.h" line="16"/>
        <source>Elevation</source>
        <translation>Magasság</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="59"/>
        <source>Up</source>
        <extracomment>Use an Unicode arrow (U+2197) when there is no abbreviation or extremly short term for &quot;Up&quot; in your language</extracomment>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="63"/>
        <source>Down</source>
        <extracomment>Use an Unicode arrow (U+2198) when there is no abbreviation or extremly short term for &quot;Down&quot; in your language</extracomment>
        <translation>Le</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="66"/>
        <source>Max</source>
        <extracomment>Use an abbreviation or a extremly short term</extracomment>
        <translation>Max</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="69"/>
        <source>Min</source>
        <extracomment>Use an abbreviation or a extremly short term</extracomment>
        <translation>Min</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="72"/>
        <source>Ascent</source>
        <translation>Emelkedés</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="74"/>
        <source>Descent</source>
        <translation>Süllyedés</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="76"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="78"/>
        <source>Minimum</source>
        <translation>Minimum</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="181"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="184"/>
        <source>ft</source>
        <translation>láb</translation>
    </message>
</context>
<context>
    <name>ElevationGraphItem</name>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="35"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="35"/>
        <source>ft</source>
        <translation>láb</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="38"/>
        <source>Ascent</source>
        <translation>Emelkedés</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="40"/>
        <source>Descent</source>
        <translation>Süllyedés</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="42"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="44"/>
        <source>Minimum</source>
        <translation>Minimum</translation>
    </message>
</context>
<context>
    <name>FileSelectWidget</name>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="46"/>
        <location filename="../src/GUI/fileselectwidget.cpp" line="51"/>
        <source>Select file</source>
        <translation>Fájl kiválasztása</translation>
    </message>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="61"/>
        <source>No output file selected.</source>
        <translation>Nincs kiválasztott kimeneti fájl.</translation>
    </message>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="71"/>
        <source>%1 is a directory.</source>
        <translation>%1 egy mappa.</translation>
    </message>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="75"/>
        <source>%1 is not writable.</source>
        <translation>%1 írásvédett.</translation>
    </message>
</context>
<context>
    <name>Format</name>
    <message>
        <location filename="../src/GUI/format.cpp" line="54"/>
        <location filename="../src/GUI/format.cpp" line="61"/>
        <location filename="../src/GUI/format.cpp" line="84"/>
        <source>ft</source>
        <translation>láb</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="57"/>
        <source>mi</source>
        <translation>mérföld</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="64"/>
        <source>nmi</source>
        <translation>tengeri mérföld</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="68"/>
        <location filename="../src/GUI/format.cpp" line="81"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="71"/>
        <source>km</source>
        <translation>km</translation>
    </message>
</context>
<context>
    <name>GUI</name>
    <message>
        <location filename="../src/GUI/gui.cpp" line="199"/>
        <source>Quit</source>
        <translation>Kilépés</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="207"/>
        <location filename="../src/GUI/gui.cpp" line="974"/>
        <location filename="../src/GUI/gui.cpp" line="992"/>
        <source>Paths</source>
        <translation>Elérési útvonalak</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="211"/>
        <location filename="../src/GUI/gui.cpp" line="934"/>
        <location filename="../src/GUI/gui.cpp" line="935"/>
        <source>Keyboard controls</source>
        <translation>Gyorsbillentyűk</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="215"/>
        <location filename="../src/GUI/gui.cpp" line="901"/>
        <source>About GPXSee</source>
        <translation>A GPXSee névjegye</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="221"/>
        <source>Open...</source>
        <translation>Megnyitás…</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="228"/>
        <source>Open directory...</source>
        <translation>Könyvtár megnyitása…</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="233"/>
        <source>Print...</source>
        <translation>Nyomtatás…</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="239"/>
        <source>Export to PDF...</source>
        <translation>Exportálás PDF-be…</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="246"/>
        <source>Export to PNG...</source>
        <translation>Exportálás PNG-be…</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="253"/>
        <source>Close</source>
        <translation>Bezárás</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="260"/>
        <source>Reload</source>
        <translation>Újratöltés</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="266"/>
        <source>Statistics...</source>
        <translation>Statisztika…</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="276"/>
        <source>Clear list</source>
        <translation>Lista törlése</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="288"/>
        <source>Load POI file...</source>
        <translation>POI fájl betöltése…</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="292"/>
        <source>Select all files</source>
        <translation>Összes fájl kijelölése</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="297"/>
        <source>Unselect all files</source>
        <translation>Összes kijelölésének visszavonása</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="302"/>
        <source>Overlap POIs</source>
        <translation>POI-k átfedése</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="307"/>
        <source>Show POI icons</source>
        <translation>POI ikonok mutatása</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="312"/>
        <source>Show POI labels</source>
        <translation>POI-k nevének mutatása</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="318"/>
        <source>Show POIs</source>
        <translation>POI-k mutatása</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="330"/>
        <source>Show map</source>
        <translation>Térkép mutatása</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="339"/>
        <source>Load map...</source>
        <translation>Térkép betöltése…</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="344"/>
        <source>Load map directory...</source>
        <translation>Térképmappa megadása…</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="347"/>
        <source>Clear tile cache</source>
        <translation>Gyorsítótár törlése</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="352"/>
        <location filename="../src/GUI/gui.cpp" line="357"/>
        <location filename="../src/GUI/gui.cpp" line="953"/>
        <source>Next map</source>
        <translation>Következő térkép</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="362"/>
        <source>Show cursor coordinates</source>
        <translation>Mutassa a kurzor koordinátáit</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="370"/>
        <source>All</source>
        <translation>Mind</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="374"/>
        <source>Raster only</source>
        <translation>Csak raszter</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="378"/>
        <source>Vector only</source>
        <translation>Csak vektor</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="385"/>
        <source>Show position</source>
        <translation>Pozíció mutatása</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="391"/>
        <source>Follow position</source>
        <translation>Pozíció követése</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="396"/>
        <source>Show coordinates</source>
        <translation>Koordináták mutatása</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="402"/>
        <source>Show motion info</source>
        <translation>Mozgásadatok mutatása</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="409"/>
        <source>Show tracks</source>
        <translation>Nyomvonalak mutatása</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="414"/>
        <source>Show routes</source>
        <translation>Útvonalak mutatása</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="419"/>
        <source>Show waypoints</source>
        <translation>Köztespontok mutatása</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="425"/>
        <source>Show areas</source>
        <translation>Területek mutatása</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="430"/>
        <source>Waypoint icons</source>
        <translation>Útpont ikonok</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="435"/>
        <source>Waypoint labels</source>
        <translation>Köztespontok neve</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="440"/>
        <source>Route waypoints</source>
        <translation>Útvonal köztespontok</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="445"/>
        <source>km/mi markers</source>
        <translation>km(mérföld) jelölők</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="453"/>
        <source>Do not show</source>
        <translation>Ne mutassa</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="457"/>
        <source>Marker only</source>
        <translation>Csak jelölő</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="461"/>
        <source>Date/time</source>
        <translation>Időpont</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="465"/>
        <source>Coordinates</source>
        <translation>Koordináták</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="469"/>
        <source>Use styles</source>
        <translation>Stílusok használata</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="487"/>
        <source>Show local DEM tiles</source>
        <translation>Helyi DEM csempék mutatása</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="490"/>
        <source>Show hillshading</source>
        <translation>Domborzatárnyékolás</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="498"/>
        <source>Show graphs</source>
        <translation>Grafikon mutatása</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="506"/>
        <location filename="../src/GUI/gui.cpp" line="1395"/>
        <location filename="../src/GUI/gui.cpp" line="1455"/>
        <source>Distance</source>
        <translation>Távolság</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="513"/>
        <location filename="../src/GUI/gui.cpp" line="763"/>
        <location filename="../src/GUI/gui.cpp" line="1397"/>
        <location filename="../src/GUI/gui.cpp" line="1457"/>
        <source>Time</source>
        <translation>Idő</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="519"/>
        <source>Show grid</source>
        <translation>Rácsvonalak mutatása</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="524"/>
        <source>Show slider info</source>
        <translation>Adatok a csúszka mellett</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="530"/>
        <source>Show tabs</source>
        <translation>Fülek mutatása</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="539"/>
        <source>Show toolbars</source>
        <translation>Gombok mutatása</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="546"/>
        <source>Total time</source>
        <translation>Teljes időtartam</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="551"/>
        <location filename="../src/GUI/gui.cpp" line="1398"/>
        <location filename="../src/GUI/gui.cpp" line="1459"/>
        <source>Moving time</source>
        <translation>Mozgásban töltött idő</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="558"/>
        <source>Metric</source>
        <translation>Metrikus</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="563"/>
        <source>Imperial</source>
        <translation>Angolszász</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="569"/>
        <source>Nautical</source>
        <translation>Tengeri</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="577"/>
        <source>Decimal degrees (DD)</source>
        <translation>Fok, tizedfok (DD)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="583"/>
        <source>Degrees and decimal minutes (DMM)</source>
        <translation>Fok, perc (DMM)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="590"/>
        <source>Degrees, minutes, seconds (DMS)</source>
        <translation>Fok, perc, másodperc (DMS)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="597"/>
        <source>Fullscreen mode</source>
        <translation>Teljes képernyős</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="604"/>
        <source>Options...</source>
        <translation>Beállítások…</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="611"/>
        <source>Next</source>
        <translation>Következő</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="616"/>
        <source>Previous</source>
        <translation>Előző</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="621"/>
        <source>Last</source>
        <translation>Utolsó</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="626"/>
        <source>First</source>
        <translation>Első</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="661"/>
        <source>&amp;File</source>
        <translation>&amp;Fájl</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="664"/>
        <source>Open recent</source>
        <translation>Legutóbbiak megnyitása</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="689"/>
        <source>&amp;Map</source>
        <translation>&amp;Térkép</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="695"/>
        <source>Layers</source>
        <translation>Rétegek</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="704"/>
        <source>&amp;Graph</source>
        <translation>&amp;Grafikon</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="735"/>
        <source>&amp;POI</source>
        <translation>&amp;POI</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="755"/>
        <source>Position</source>
        <translation>Pozíció</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="981"/>
        <location filename="../src/GUI/gui.cpp" line="999"/>
        <source>CRS directory:</source>
        <translation>CRS könyvtár:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="987"/>
        <location filename="../src/GUI/gui.cpp" line="1005"/>
        <source>Symbols directory:</source>
        <translation>Szimbólumkönyvtár:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1053"/>
        <source>Open directory</source>
        <translation>Könyvtár megnyitása</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1126"/>
        <location filename="../src/GUI/gui.cpp" line="1815"/>
        <location filename="../src/GUI/gui.cpp" line="1915"/>
        <source>Don&apos;t show again</source>
        <translation>Ne mutassa újra</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1978"/>
        <source>Clear &quot;%1&quot; tile cache?</source>
        <translation>&quot;%1&quot; csempe gyorsítótár törlése?</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/GUI/gui.cpp" line="2001"/>
        <source>Download %n DEM tiles?</source>
        <translation>
            <numerusform>%n DEM csempe letöltése?</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="716"/>
        <source>&amp;Data</source>
        <translation>&amp;Adatok</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="476"/>
        <source>Download data DEM</source>
        <translation>DEM adat letöltése</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="482"/>
        <source>Download map DEM</source>
        <translation>DEM térkép letöltése</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="721"/>
        <source>Position info</source>
        <translation>Pozíció információ</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="747"/>
        <source>DEM</source>
        <translation>DEM</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="762"/>
        <source>&amp;Settings</source>
        <translation>&amp;Beállítások</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="767"/>
        <source>Units</source>
        <translation>Mértékegységek</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="772"/>
        <source>Coordinates format</source>
        <translation>Koordináta formátum</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="785"/>
        <source>&amp;Help</source>
        <translation>&amp;Segítség</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="812"/>
        <source>File</source>
        <translation>Műveletgombok</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="822"/>
        <source>Show</source>
        <translation>Szűrőgombok</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="830"/>
        <source>Navigation</source>
        <translation>Léptető gombok</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="903"/>
        <location filename="../src/GUI/gui.cpp" line="911"/>
        <source>Version %1</source>
        <translation>%1. verzió</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="906"/>
        <location filename="../src/GUI/gui.cpp" line="915"/>
        <source>GPXSee is distributed under the terms of the GNU General Public License version 3. For more info about GPXSee visit the project homepage at %1.</source>
        <translation>A GPXSee-t a GNU General Public License 3. verziója szerint terjesztik. A GPXSee-re vonatkozó további információkért látogasson el a projekt honlapjára a %1 oldalon.</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="938"/>
        <source>Next file</source>
        <translation>Következő fájl</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="939"/>
        <source>Previous file</source>
        <translation>Előző fájl</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="941"/>
        <source>First file</source>
        <translation>Első fájl</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="943"/>
        <source>Last file</source>
        <translation>Utolsó fájl</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="944"/>
        <source>Append file</source>
        <translation>További fájl (hozzáadás)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="945"/>
        <source>Next/Previous</source>
        <translation>Következő/előző</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="947"/>
        <source>Toggle graph type</source>
        <translation>Grafikon: idő/távolság váltás</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="949"/>
        <source>Toggle time type</source>
        <translation>Idő: összes/mozgásban váltás</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="951"/>
        <source>Toggle position info</source>
        <translation>Pozíció információ váltás</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="955"/>
        <source>Previous map</source>
        <translation>Előző térkép</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="956"/>
        <source>Zoom in</source>
        <translation>Nagyítás</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="958"/>
        <source>Zoom out</source>
        <translation>Kicsinyítés</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="960"/>
        <source>Digital zoom</source>
        <translation>Digitális nagyítás</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="961"/>
        <source>Zoom</source>
        <translation>Nagyítás</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="962"/>
        <source>Copy coordinates</source>
        <translation>Koordináták másolása</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="963"/>
        <source>Left Click</source>
        <translation>Bal kattintás</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="977"/>
        <location filename="../src/GUI/gui.cpp" line="995"/>
        <source>Map directory:</source>
        <translation>Térképmappa:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="979"/>
        <location filename="../src/GUI/gui.cpp" line="997"/>
        <source>POI directory:</source>
        <translation>POI mappa:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="983"/>
        <location filename="../src/GUI/gui.cpp" line="1001"/>
        <source>DEM directory:</source>
        <translation>DEM mappa:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="985"/>
        <location filename="../src/GUI/gui.cpp" line="1003"/>
        <source>Styles directory:</source>
        <translation>Stílusok mappa:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="989"/>
        <location filename="../src/GUI/gui.cpp" line="1007"/>
        <source>Tile cache directory:</source>
        <translation>Gyorsítótár mappa:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1018"/>
        <location filename="../src/GUI/gui.cpp" line="1021"/>
        <source>Open file</source>
        <translation>Fájl megnyitása</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1118"/>
        <source>Error loading data file:</source>
        <translation>Adatfájl betöltési hiba:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1121"/>
        <location filename="../src/GUI/gui.cpp" line="1233"/>
        <source>Line: %1</source>
        <translation>Sor: %1</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1200"/>
        <location filename="../src/GUI/gui.cpp" line="1203"/>
        <source>Open POI file</source>
        <translation>POI fájl megnyitása</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1230"/>
        <source>Error loading POI file:</source>
        <translation>Hiba a POI fájl betöltése során:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1377"/>
        <location filename="../src/GUI/gui.cpp" line="1435"/>
        <source>Tracks</source>
        <translation>Nyomvonalak</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1379"/>
        <location filename="../src/GUI/gui.cpp" line="1437"/>
        <source>Routes</source>
        <translation>Útvonalak</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1381"/>
        <location filename="../src/GUI/gui.cpp" line="1439"/>
        <source>Waypoints</source>
        <translation>Köztespontok</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1383"/>
        <location filename="../src/GUI/gui.cpp" line="1441"/>
        <source>Areas</source>
        <translation>Területek</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1387"/>
        <location filename="../src/GUI/gui.cpp" line="1389"/>
        <location filename="../src/GUI/gui.cpp" line="1446"/>
        <location filename="../src/GUI/gui.cpp" line="1448"/>
        <source>Date</source>
        <translation>Dátum</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1410"/>
        <location filename="../src/GUI/gui.cpp" line="1413"/>
        <location filename="../src/GUI/gui.cpp" line="1414"/>
        <source>Statistics</source>
        <translation>Összesítés</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1431"/>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1754"/>
        <location filename="../src/GUI/gui.cpp" line="1757"/>
        <source>Open map file</source>
        <translation>Térképfájl megnyitása</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1809"/>
        <location filename="../src/GUI/gui.cpp" line="1866"/>
        <location filename="../src/GUI/gui.cpp" line="1885"/>
        <location filename="../src/GUI/gui.cpp" line="1909"/>
        <source>Error loading map:</source>
        <translation>Térképbetöltési hiba:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1949"/>
        <source>Select map directory</source>
        <translation>Térképmappa választása</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1998"/>
        <source>DEM tiles download limit exceeded. If you really need data for such a huge area, download the files manually.</source>
        <translation>DEM csempe letöltési limit túllépve. Ha valóban szüksége van ilyen nagy területre vonatkozó adatokra, töltse le a fájlokat kézzel.</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2014"/>
        <source>Could not download all required DEM files.</source>
        <translation>Nem volt letölthető minden szükséges DEM fájl.</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2034"/>
        <source>No local DEM tiles found.</source>
        <translation>Nem található helyi DEM csempe.</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2048"/>
        <source>No files loaded</source>
        <translation>Nincs betöltött fájl</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/GUI/gui.cpp" line="2052"/>
        <source>%n files</source>
        <translation>
            <numerusform>%n fájl</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>GearRatioGraph</name>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="12"/>
        <location filename="../src/GUI/gearratiograph.h" line="17"/>
        <source>Gear ratio</source>
        <translation>Áttétel</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="28"/>
        <source>Top</source>
        <translation>Max</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="30"/>
        <source>Min</source>
        <translation>Min</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="32"/>
        <source>Max</source>
        <translation>Max</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="35"/>
        <source>Most used</source>
        <translation>Legtöbbször használt</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="37"/>
        <source>Minimum</source>
        <translation>Minimum</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="39"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
</context>
<context>
    <name>GearRatioGraphItem</name>
    <message>
        <location filename="../src/GUI/gearratiographitem.cpp" line="37"/>
        <source>Minimum</source>
        <translation>Minimum</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiographitem.cpp" line="38"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiographitem.cpp" line="39"/>
        <source>Most used</source>
        <translation>Leggyakrabban használt</translation>
    </message>
</context>
<context>
    <name>GraphView</name>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="74"/>
        <source>Data not available</source>
        <translation>Nem elérhető</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="94"/>
        <location filename="../src/GUI/graphview.cpp" line="199"/>
        <source>Distance</source>
        <translation>Távolság</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="131"/>
        <location filename="../src/GUI/graphview.cpp" line="139"/>
        <source>ft</source>
        <translation>láb</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="134"/>
        <source>mi</source>
        <translation>mérföld</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="142"/>
        <source>nmi</source>
        <translation>tengeri mérföld</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="147"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="150"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="156"/>
        <source>s</source>
        <translation>mp</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="159"/>
        <source>min</source>
        <translation>perc</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="162"/>
        <source>h</source>
        <translation>óra</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="201"/>
        <source>Time</source>
        <translation>Idő</translation>
    </message>
</context>
<context>
    <name>HeartRateGraph</name>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="11"/>
        <source>bpm</source>
        <translation>ütés/perc</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="12"/>
        <location filename="../src/GUI/heartrategraph.h" line="16"/>
        <source>Heart rate</source>
        <translation>Pulzusszám</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="28"/>
        <source>Avg</source>
        <translation>Átl.</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="30"/>
        <source>Max</source>
        <translation>Max</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="33"/>
        <source>Average</source>
        <translation>Átlag</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="35"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
</context>
<context>
    <name>HeartRateGraphItem</name>
    <message>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="19"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="20"/>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="22"/>
        <source>bpm</source>
        <translation>ütés</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="21"/>
        <source>Average</source>
        <translation>Átlag</translation>
    </message>
</context>
<context>
    <name>MapItem</name>
    <message>
        <location filename="../src/GUI/mapitem.cpp" line="80"/>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <location filename="../src/GUI/mapitem.cpp" line="82"/>
        <source>File</source>
        <translation>Műveletgombok</translation>
    </message>
</context>
<context>
    <name>MapList</name>
    <message>
        <location filename="../src/map/maplist.cpp" line="158"/>
        <source>Supported files</source>
        <translation>Támogatott fájltípusok</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="162"/>
        <source>AlpineQuest maps</source>
        <translation>AlpineQuest térképek</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="164"/>
        <source>Garmin IMG maps</source>
        <translation>Garmin IMG térképek</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="166"/>
        <source>Garmin JNX maps</source>
        <translation>Garmin JNX térképek</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="167"/>
        <source>BSB nautical charts</source>
        <translation>BSB tengeri térképek</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="163"/>
        <source>GEMF maps</source>
        <translation>GEMF térképek</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="160"/>
        <source>Electronic Navigational Charts</source>
        <translation>Elektronikus navigációs térképek</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="168"/>
        <source>KMZ maps</source>
        <translation>KMZ térképek</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="169"/>
        <source>Mapsforge maps</source>
        <translation>Mapsforge térképek</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="170"/>
        <source>OziExplorer maps</source>
        <translation>OziExplorer térképek</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="171"/>
        <source>MBTiles maps</source>
        <translation>MBTiles térképek</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="172"/>
        <source>Orux maps</source>
        <translation>Orux térképek</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="173"/>
        <source>QuickChart maps</source>
        <translation>QuickChart térképek</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="175"/>
        <source>Osmdroid SQLite maps</source>
        <translation>Osmdroid SQLite térképek</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="178"/>
        <source>TrekBuddy maps/atlases</source>
        <translation>TrekBuddy térképek</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="180"/>
        <source>GeoTIFF images</source>
        <translation>GeoTIFF képek</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="184"/>
        <source>All files</source>
        <translation>Minden fájl</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="174"/>
        <source>TwoNav maps</source>
        <translation>TwoNav térképek</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="176"/>
        <source>Locus/OsmAnd/RMaps SQLite maps</source>
        <translation>Locus/OsmAnd/RMaps SQLite térképek</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="181"/>
        <source>World-file georeferenced images</source>
        <translation>Georeferált világ-fájlképek</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="183"/>
        <source>Online map sources</source>
        <translation>Online térképforrások</translation>
    </message>
</context>
<context>
    <name>MotionInfoItem</name>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="87"/>
        <source>kn</source>
        <translation>csomó</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="90"/>
        <source>mi/h</source>
        <translation>mph</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="93"/>
        <source>km/h</source>
        <translation>km/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="100"/>
        <source>ft/min</source>
        <translation>láb/perc</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="103"/>
        <source>m/min</source>
        <translation>m/perc</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="86"/>
        <source>Standard</source>
        <translation>Alap</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="91"/>
        <source>Non-HiDPI maps are loaded as HiDPI maps. The map is sharp but map objects are small/hard to read.</source>
        <translation>A nem HiDPI térképek HiDPI térképként töltődnek be. A térkép éles lesz, de a térképobjektumok kicsik / nehezen olvashatóak lesznek.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="93"/>
        <source>Non-HiDPI maps are loaded such as they are. Map objects have the expected size but the map is blurry.</source>
        <translation>A nem HiDPI térképek változatlan formában töltődnek be. A térképobjektumok a várt méretűek, de a térkép kissé homályos lesz.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="103"/>
        <source>Input</source>
        <translation>Bemenet</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="105"/>
        <source>Output</source>
        <translation>Kimenet</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="137"/>
        <source>HiDPI display mode</source>
        <translation>HiDPI megjelenítési mód</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="177"/>
        <source>Track width:</source>
        <translation>Nyomvonalak vonalvastagsága:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="178"/>
        <source>Track style:</source>
        <translation>Nyomvonalak stílusa:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="194"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="199"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="204"/>
        <source>Width:</source>
        <translation>Vastagság:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="195"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="200"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="205"/>
        <source>Style:</source>
        <translation>Stílus:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="196"/>
        <source>Tracks</source>
        <translation>Nyomvonalak</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="180"/>
        <source>Route width:</source>
        <translation>Útvonalak vonalvastagsága:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="181"/>
        <source>Route style:</source>
        <translation>Útvonalak vonalstílusa:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="201"/>
        <source>Routes</source>
        <translation>Útvonalak</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="183"/>
        <source>Area border width:</source>
        <translation>Terület szegélyszélessége:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="184"/>
        <source>Area border style:</source>
        <translation>Területhatár stílusa:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="185"/>
        <source>Area fill opacity:</source>
        <translation>Átlátszóság:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="207"/>
        <source>Areas</source>
        <translation>Területek határvonala</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="187"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="210"/>
        <source>Base color:</source>
        <translation>Alapszín (egy nyomvonal):</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="188"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="211"/>
        <source>Palette shift:</source>
        <translation>Színhasonlóság (továbbiak):</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="171"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="275"/>
        <source>Use anti-aliasing</source>
        <translation>Élsimítás be</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="243"/>
        <source>Waypoint color:</source>
        <translation>Köztespont szín:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="244"/>
        <source>Waypoint size:</source>
        <translation>Köztespont méret:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="251"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="256"/>
        <source>Color:</source>
        <translation>Szín:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="252"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="257"/>
        <source>Size:</source>
        <translation>Méret:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="253"/>
        <source>Waypoints</source>
        <translation>Köztespontok</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="246"/>
        <source>POI color:</source>
        <translation>POI szín:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="247"/>
        <source>POI size:</source>
        <translation>POI méret:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="258"/>
        <source>POIs</source>
        <translation>POI-k</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="281"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="287"/>
        <source>Line width:</source>
        <translation>Vonalvastagság:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="282"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="288"/>
        <source>Slider color:</source>
        <translation>Csúszka színe:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="313"/>
        <source>Background color:</source>
        <translation>Háttérszín:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="326"/>
        <source>Paths</source>
        <translation>Utak</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="327"/>
        <source>Points</source>
        <translation>Pontok</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="328"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="768"/>
        <source>Graphs</source>
        <translation>Grafikonok</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="329"/>
        <source>Map</source>
        <translation>Térkép</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="336"/>
        <source>Moving average window size</source>
        <translation>Interpoláció ablakmérete</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="361"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="371"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="495"/>
        <source>Elevation:</source>
        <translation>Magasság:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="362"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="372"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="494"/>
        <source>Speed:</source>
        <translation>Sebesség:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="363"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="373"/>
        <source>Heart rate:</source>
        <translation>Pulzusszám:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="364"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="374"/>
        <source>Cadence:</source>
        <translation>Ütem:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="365"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="375"/>
        <source>Power:</source>
        <translation>Teljesítmény:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="360"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="378"/>
        <source>Smoothing</source>
        <translation>Grafikon simítása</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="354"/>
        <source>Eliminate GPS outliers</source>
        <translation>Kiugró GPS adatok figyelmen kívül hagyása</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="391"/>
        <source>Automatic</source>
        <translation>Automatikus</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="392"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="446"/>
        <source>Custom</source>
        <translation>Egyéni</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="405"/>
        <source>mi/h</source>
        <translation>mph</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="408"/>
        <source>kn</source>
        <translation>csomó</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="411"/>
        <source>km/h</source>
        <translation>km/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="415"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="795"/>
        <source>s</source>
        <translation>mp</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="538"/>
        <source>Minimal speed:</source>
        <translation>Ennél kisebb sebesség:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="539"/>
        <source>Minimal duration:</source>
        <translation>legalább ennyi ideig:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="426"/>
        <source>Computed from distance/time</source>
        <translation>Számított sebesség</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="427"/>
        <source>Recorded by device</source>
        <translation>Az eszköz által rögzített</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="432"/>
        <source>Show secondary speed</source>
        <translation>Másodlagos sebesség mutatása</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="435"/>
        <source>GPS data</source>
        <translation>GPS adat</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="436"/>
        <source>DEM data</source>
        <translation>DEM adat</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="441"/>
        <source>Show secondary elevation</source>
        <translation>Másodlagos emelkedés mutatása</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="444"/>
        <source>UTC</source>
        <translation>UTC</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="465"/>
        <source>Use segments</source>
        <translation>Szakaszok használata</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="496"/>
        <source>Time zone:</source>
        <translation>Időzóna:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="510"/>
        <source>Speed</source>
        <translation>Sebesség</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="515"/>
        <source>Elevation</source>
        <translation>Magasság</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="521"/>
        <source>Time zone</source>
        <translation>Időzóna</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="551"/>
        <source>Filtering</source>
        <translation>Részletesség</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="550"/>
        <source>Sources</source>
        <translation>Adatforrások</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="78"/>
        <source>Select the proper coordinate reference system (CRS) of maps without a CRS definition (JNX, KMZ and World file maps).</source>
        <translation>Válassza ki a megfelelő koordináta referenciarendszert (CRS) a CRS-definíció nélküli térképekhez (JNX, KMZ és világfájltérképek).</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="81"/>
        <source>Select the desired projection of vector maps (IMG, Mapsforge and ENC maps). The projection must be valid for the whole map area.</source>
        <translation>Válassza ki a vektoros térképek kívánt vetületét (IMG, Mapsforge és ENC térképek). A vetületnek a térkép teljes területére érvényesnek kell lennie.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="147"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="154"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="160"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="228"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="235"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="273"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="639"/>
        <source>px</source>
        <translation>pont</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="309"/>
        <source>Info background</source>
        <translation>Info háttérszín</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="315"/>
        <source>Crosshair color:</source>
        <translation>Szálkereszt színe:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="316"/>
        <source>Info color:</source>
        <translation>Info színe:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="552"/>
        <source>Pause detection</source>
        <translation>Megállás érzékelés</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="564"/>
        <source>mi</source>
        <translation>mérföld</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="567"/>
        <source>nmi</source>
        <translation>tengeri mérföld</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="570"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="574"/>
        <source>Radius:</source>
        <translation>Láthatóság sugara:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="580"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="888"/>
        <source>POI</source>
        <translation>POI</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="597"/>
        <source>Use HTTP authentication</source>
        <translation>HTTP hitelesítés használata</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="603"/>
        <source>Use $lat and $lon for NYY/SYY and EXXX/WXXX in the URL.</source>
        <translation>Használj az URL -ben $lat és $lon értékeket a NYY/SYY és az EXXX/WXXX-hez .</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="608"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="621"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="206"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="314"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="655"/>
        <source>Opacity:</source>
        <translation>Átlátszatlanság:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="657"/>
        <source>Blur radius:</source>
        <translation>Elhomályosítási sugár:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="659"/>
        <source>Azimuth:</source>
        <translation>Azimut:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="660"/>
        <source>Altitude:</source>
        <translation>Magasság:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="661"/>
        <source>Z Factor:</source>
        <translation>Z-tényező:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="666"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="700"/>
        <source>Source</source>
        <translation>Forrás</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="667"/>
        <source>Hillshading</source>
        <translation>Domborzatárnyékolás</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="687"/>
        <source>Plugin:</source>
        <translation>Beépülő:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="707"/>
        <source>WYSIWYG</source>
        <translation>Alakhű</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="85"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="708"/>
        <source>High-Resolution</source>
        <translation>Nagy felbontás</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="388"/>
        <source>Detect pauses</source>
        <translation>Szünetek érzékelése</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="537"/>
        <source>Detection:</source>
        <translation>Érzékelés:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="656"/>
        <source>Lightening:</source>
        <translation>Világosítás:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="713"/>
        <source>The printed area is approximately the display area. The map zoom level does not change.</source>
        <translation>A nyomtatott terület megközelítőleg a megjelenítési terület. A térképnagyítás mértéke nem változik.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="715"/>
        <source>The zoom level will be changed so that the whole content (tracks/waypoints) fits to the printed area and the map resolution is as close as possible to the print resolution.</source>
        <translation>A nagyítás mértéke megváltozik, hogy a teljes tartalom (nyomvonal / köztespontok) illeszkedjen a nyomtatott területhez, és a térkép felbontása a lehető legközelebb legyen a nyomtatási felbontáshoz.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="731"/>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="733"/>
        <source>Date</source>
        <translation>Dátum</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="735"/>
        <source>Distance</source>
        <translation>Távolság</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="737"/>
        <source>Time</source>
        <translation>Idő</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="739"/>
        <source>Moving time</source>
        <translation>Mozgásban töltött idő</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="741"/>
        <source>Item count (&gt;1)</source>
        <translation>nyomvonalak száma (ha&gt;1)</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="756"/>
        <source>Separate graph page</source>
        <translation>A grafikon külön oldalra</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="766"/>
        <source>Print mode</source>
        <translation>Nyomtatási mód</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="767"/>
        <source>Header</source>
        <translation>Fejléc</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="775"/>
        <source>Use OpenGL</source>
        <translation>OpenGL használata</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="777"/>
        <source>Enable HTTP/2</source>
        <translation>HTTP/2 engedélyezése</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="783"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="789"/>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="801"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="809"/>
        <source>Image cache size:</source>
        <translation>Kép gyorsítótár mérete:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="803"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="811"/>
        <source>Connection timeout:</source>
        <translation>Kapcsolat időtúllépés:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="445"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="846"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="897"/>
        <source>System</source>
        <translation>Rendszer</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="112"/>
        <source>Input:</source>
        <translation>Bemenet:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="115"/>
        <source>Output:</source>
        <translation>Kimenet:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="136"/>
        <source>Projection</source>
        <translation>Vetület</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="802"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="810"/>
        <source>DEM cache size:</source>
        <translation>DEM gyorsítótár:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="830"/>
        <source>Select the initial paths of the file open dialogues. Leave the field empty for the system default.</source>
        <translation>Alapértelmezetten megnyíló mappa a lenti elemekhez. Üresen hagyva a mezőt, a program által alapértelmezett.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="834"/>
        <source>Data:</source>
        <translation>Adat:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="835"/>
        <source>Maps:</source>
        <translation>Térképek:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="836"/>
        <source>POI:</source>
        <translation>POI:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="847"/>
        <source>Initial paths</source>
        <translation>Könyvtárak</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="883"/>
        <source>Appearance</source>
        <translation>Megjelenés</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="885"/>
        <source>Maps</source>
        <translation>Térképek</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="887"/>
        <source>Data</source>
        <translation>Adatok</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="890"/>
        <source>DEM</source>
        <translation>DEM</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="893"/>
        <source>Position</source>
        <translation>Pozíció</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="895"/>
        <source>Print &amp; Export</source>
        <translation>Kimenet</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="930"/>
        <source>Options</source>
        <translation>Beállítások</translation>
    </message>
</context>
<context>
    <name>PDFExportDialog</name>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="28"/>
        <source>PDF files</source>
        <translation>PDF fájlok</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="28"/>
        <source>All files</source>
        <translation>Minden fájl</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="56"/>
        <source>Portrait</source>
        <translation>Álló</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="57"/>
        <source>Landscape</source>
        <translation>Fekvő</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="67"/>
        <source>in</source>
        <translation>hüvelyk</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="67"/>
        <source>cm</source>
        <translation>cm</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="73"/>
        <source>Page Setup</source>
        <translation>Oldalbeállítás</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="76"/>
        <source>Page size:</source>
        <translation>Oldalméret:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="77"/>
        <source>Resolution:</source>
        <translation>Felbontás:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="78"/>
        <source>Orientation:</source>
        <translation>Tájolás:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="79"/>
        <source>Margins:</source>
        <translation>Margók:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="85"/>
        <source>File:</source>
        <translation>Fájl:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="92"/>
        <source>Output file</source>
        <translation>Kimeneti fájl</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="99"/>
        <source>Export</source>
        <translation>Exportálás</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="119"/>
        <source>Export to PDF</source>
        <translation>Exportálás PDF-be</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="127"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
</context>
<context>
    <name>PNGExportDialog</name>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="25"/>
        <source>PNG files</source>
        <translation>PNG fájlok</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="25"/>
        <source>All files</source>
        <translation>Minden fájl</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="34"/>
        <location filename="../src/GUI/pngexportdialog.cpp" line="39"/>
        <location filename="../src/GUI/pngexportdialog.cpp" line="43"/>
        <source>px</source>
        <translation>pont</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="45"/>
        <source>Use anti-aliasing</source>
        <translation>Élsimítás be</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="49"/>
        <source>Image Setup</source>
        <translation>Kép beállítása</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="52"/>
        <source>Image width:</source>
        <translation>Kép szélessége:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="53"/>
        <source>Image height:</source>
        <translation>Kép magassága:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="54"/>
        <source>Margins:</source>
        <translation>Margók:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="61"/>
        <source>File:</source>
        <translation>Fájl:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="68"/>
        <source>Output file</source>
        <translation>Kimeneti fájl</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="75"/>
        <source>Export</source>
        <translation>Exportálás</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="95"/>
        <source>Export to PNG</source>
        <translation>Exportálás PNG-be</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="103"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
</context>
<context>
    <name>PolygonItem</name>
    <message>
        <location filename="../src/GUI/areaitem.cpp" line="18"/>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <location filename="../src/GUI/areaitem.cpp" line="20"/>
        <source>Description</source>
        <translation>Leírás</translation>
    </message>
</context>
<context>
    <name>PowerGraph</name>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="11"/>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="12"/>
        <location filename="../src/GUI/powergraph.h" line="16"/>
        <source>Power</source>
        <translation>Teljesítmény</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="28"/>
        <source>Avg</source>
        <translation>Átl.</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="30"/>
        <source>Max</source>
        <translation>Max</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="33"/>
        <source>Average</source>
        <translation>Átlag</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="35"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
</context>
<context>
    <name>PowerGraphItem</name>
    <message>
        <location filename="../src/GUI/powergraphitem.cpp" line="18"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraphitem.cpp" line="19"/>
        <location filename="../src/GUI/powergraphitem.cpp" line="21"/>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraphitem.cpp" line="20"/>
        <source>Average</source>
        <translation>Átlag</translation>
    </message>
</context>
<context>
    <name>RouteItem</name>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="16"/>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="18"/>
        <source>Description</source>
        <translation>Leírás</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="20"/>
        <source>Comment</source>
        <translation>Megjegyzés</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="21"/>
        <source>Distance</source>
        <translation>Távolság</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="32"/>
        <source>Links</source>
        <translation>Hivatkozások</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="38"/>
        <source>File</source>
        <translation>Műveletgombok</translation>
    </message>
</context>
<context>
    <name>ScaleItem</name>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="108"/>
        <source>mi</source>
        <translation>mérföld</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="109"/>
        <location filename="../src/GUI/scaleitem.cpp" line="112"/>
        <source>ft</source>
        <translation>láb</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="111"/>
        <source>nmi</source>
        <translation>tengeri mérföld</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="114"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="115"/>
        <source>m</source>
        <translation>m</translation>
    </message>
</context>
<context>
    <name>SpeedGraph</name>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="15"/>
        <location filename="../src/GUI/speedgraph.h" line="18"/>
        <source>Speed</source>
        <translation>Sebesség</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="30"/>
        <source>min/km</source>
        <translation>perc/km</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="31"/>
        <source>min/mi</source>
        <translation>perc/mérföld</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="31"/>
        <source>min/nmi</source>
        <translation>perc/tengeri mérföld</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="34"/>
        <source>Avg</source>
        <translation>Átl.</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="36"/>
        <source>Max</source>
        <translation>Max</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="39"/>
        <source>Average</source>
        <translation>Átlag</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="41"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="44"/>
        <source>Pace</source>
        <translation>Iram</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="134"/>
        <source>kn</source>
        <translation>csomó</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="137"/>
        <source>mi/h</source>
        <translation>mph</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="140"/>
        <source>km/h</source>
        <translation>km/h</translation>
    </message>
</context>
<context>
    <name>SpeedGraphItem</name>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="25"/>
        <source>mi/h</source>
        <translation>mph</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="26"/>
        <source>kn</source>
        <translation>csomó</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="26"/>
        <source>km/h</source>
        <translation>km/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="29"/>
        <source>min/km</source>
        <translation>perc/km</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="30"/>
        <source>min/mi</source>
        <translation>perc/mérföld</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="30"/>
        <source>min/nmi</source>
        <translation>perc/tengeri mérföld</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="33"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="35"/>
        <source>Average</source>
        <translation>Átlag</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="37"/>
        <source>Pace</source>
        <translation>Iram</translation>
    </message>
</context>
<context>
    <name>TemperatureGraph</name>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="12"/>
        <location filename="../src/GUI/temperaturegraph.h" line="16"/>
        <source>Temperature</source>
        <translation>Hőmérséklet</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="28"/>
        <source>Avg</source>
        <translation>Átl.</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="30"/>
        <source>Min</source>
        <translation>Min</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="32"/>
        <source>Max</source>
        <translation>Max</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="35"/>
        <source>Average</source>
        <translation>Átlag</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="37"/>
        <source>Minimum</source>
        <translation>Minimum</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="39"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="112"/>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="116"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>TemperatureGraphItem</name>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="23"/>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="23"/>
        <source>F</source>
        <translation>F</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="26"/>
        <source>Average</source>
        <translation>Átlag</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="28"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="30"/>
        <source>Minimum</source>
        <translation>Minimum</translation>
    </message>
</context>
<context>
    <name>TrackItem</name>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="15"/>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="17"/>
        <source>Description</source>
        <translation>Leírás</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="19"/>
        <source>Comment</source>
        <translation>Megjegyzés</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="20"/>
        <source>Distance</source>
        <translation>Távolság</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="23"/>
        <source>Total time</source>
        <translation>Időtartam</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="25"/>
        <source>Moving time</source>
        <translation>Mozgásban</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="28"/>
        <source>Date</source>
        <translation>Dátum</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="40"/>
        <source>Links</source>
        <translation>Hivatkozások</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="46"/>
        <source>File</source>
        <translation>Műveletgombok</translation>
    </message>
</context>
<context>
    <name>WaypointItem</name>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="26"/>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="27"/>
        <source>Coordinates</source>
        <translation>Koordináták</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="34"/>
        <source>Elevation</source>
        <translation>Magasság</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="38"/>
        <source>Date</source>
        <translation>Dátum</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="43"/>
        <source>Description</source>
        <translation>Leírás</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="47"/>
        <source>Comment</source>
        <translation>Megjegyzés</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="50"/>
        <source>Symbol</source>
        <translation>Szimbólum</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="55"/>
        <source>Address</source>
        <translation>Cím</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="58"/>
        <source>Phone</source>
        <translation>Telefon</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="68"/>
        <source>Links</source>
        <translation>Hivatkozások</translation>
    </message>
</context>
</TS>
